Learn R Programming

MethylSeekR (version 1.12.0)

readSNPTable: Load SNP table

Description

Loading SNPs from tab-delimited file or saved GRanges object

Usage

readSNPTable(FileName, seqLengths, format = "text")

Arguments

FileName
File Name.
seqLengths
A named vector indicating the chromosome lengths of the genome used.
format
File format. If format is set to "text", the argument FileName should refer to a tab-delimited text file in the format: chromosome position, where each line stands for a SNP. If format="GRanges", the file is assumed to be a GRanges object, containing the SNP coordinates, saved in rds format.

Value

A GRanges object containing the coordinates of the SNPs.

Examples

Run this code

library(MethylSeekR)

# get chromosome lengths
library("BSgenome.Hsapiens.UCSC.hg18")
sLengths=seqlengths(Hsapiens)

#read SNP data
snpFname <- system.file("extdata", "SNVs_hg18_chr22.tab",
package="MethylSeekR")
snps.gr <- readSNPTable(FileName=snpFname, seqLengths=sLengths)


Run the code above in your browser using DataLab